#include <QtGui/QApplication>
#include "mainwindow.h"

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    QApplication::setApplicationName("enhanced-lockscreen");
    QApplication::setOrganizationName("MohammadAG");
    QApplication::setApplicationVersion("0.2");
    MainWindow w;
#ifndef Q_WS_MAEMO_5
    w.show();
#endif

    return a.exec();
}
